[gnome-control-center] displays: bgo#592412 - Make 'Mirrored Displays' string consistent with GnomeRRLabeler



commit f0be9146d418d7db8dce6826134e8e7ab15af911
Author: Federico Mena Quintero <federico gnome org>
Date:   Mon Sep 3 14:07:29 2012 -0500

    displays: bgo#592412 - Make 'Mirrored Displays' string consistent with GnomeRRLabeler
    
    We had 'Mirror displays' as a command in the control center, but 'Mirror screens' as a description in
    GnomeRRLabeler.  Now we have 'Mirrored Displays' as a description of the current state.
    
    Signed-off-by: Federico Mena Quintero <federico gnome org>

 panels/display/cc-display-panel.c |   10 ++++++----
 1 files changed, 6 insertions(+), 4 deletions(-)
---
diff --git a/panels/display/cc-display-panel.c b/panels/display/cc-display-panel.c
index 9dbc276..7e24033 100644
--- a/panels/display/cc-display-panel.c
+++ b/panels/display/cc-display-panel.c
@@ -613,12 +613,14 @@ rebuild_mirror_screens (CcDisplayPanel *self)
 static char *
 mirror_monitor_name (void)
 {
+  /* Keep this string in sync with gnome-desktop/libgnome-desktop/gnome-rr-labeler.c */
+
   /* Translators:  this is the feature where what you see on your laptop's
    * screen is the same as your external monitor.  Here, "Mirror" is being
    * used as an adjective, not as a verb.  For example, the Spanish
    * translation could be "Pantallas en Espejo", *not* "Espejar Pantallas".
    */
-  return g_strdup (_("Mirror Displays"));
+  return g_strdup (_("Mirrored Displays"));
 }
 
 static void
@@ -613,12 +613,14 @@ rebuild_mirror_screens (CcDisplayPanel *self)
   /* Translators:  this is the feature where what you see on your laptop's
-   * screen is the same as your external monitor.  Here, "Mirror" is being
-   * used as an adjective, not as a verb.  For example, the Spanish
-   * translation could be "Pantallas en Espejo", *not* "Espejar Pantallas".
+   * screen is the same as your external projector.  Here, "Mirrored" is being
+   * used as an adjective.  For example, the Spanish translation could be
+   * "Pantallas en Espejo".
    */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]